@@ -72,9 +72,9 @@ class Model(object):
     1
     
     >>> [t.day.year for t in Test.find(
-    ...     filter  = lambda x: 3 not in x.foo,
-    ...     order   = lambda x: x.day)]
-    [1999, 2000]
+    ...     filter  = lambda x: t.day.year > 1900 and 3 not in x.foo,
+    ...     order   = (lambda x: x.day, -1))]
+    [2000, 1999]
     
     >>> Test.find_one().delete()
     >>> Test.count()
@@ -222,6 +222,10 @@ class Model(object):
             
     def __str__(self):
         return self.__unicode__().encode('utf-8')
+    
+    def as_dict(self, keys=None):
+        keys = keys or self._properties.keys()
+        return dict((k, getattr(self, k)) for k in keys)
 
 
 class BaseProperty(object):
